import 'dart:async';
import 'dart:typed_data';

import 'package:flutter/services.dart';
import 'package:meta/meta.dart';
import 'package:quantize_plugin/quant_config.dart';
import 'package:quantize_plugin/quant_result.dart';

class QuantizePlugin {
  static const MethodChannel _channel = const MethodChannel('quantize_plugin');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<QuantizeResult> quantize(QuantConfig qCfg) async {
    _channel.invokeMethod("quantize", {
      "numColors": qCfg.numColor,
      "quality": qCfg.quality,
      "width": qCfg.width,
      "height": qCfg.height,
      "dither": qCfg.dither,
      "srcW": qCfg.srcW,
      "srcH": qCfg.srcH,
    }).then((result) {
      // store response
      QuantizeResult quantized = QuantizeResult.fromChannel(
        config: qCfg, // needed for rendering
        ind: result[0] as Uint8List,
        pal: result[1] as Uint8List,
      );

      return quantized;
    });

    // nothing
  }

  static Future<bool> load({
    @required Int32List original,
    @required int width,
    @required int height,
  }) async {
    dynamic params = {
      "original": original,
      "width": width,
      "height": height,
    };
    final bool loaded = await _channel.invokeMethod("load_original", params);
    return loaded;
  }
}
